BarcodeX class

Data model for a barcode.

Constructors

BarcodeX({required Barcode barcode, required Size imageSize})
Constructor.

Properties

barcode → Barcode
barcode : that found when process the CameraImage.
final
cornerPoints List<Offset>
List of Barcode corner points in Offset.
no setter
hashCode int
The hash code for this object.
no setterinherited
imageSize Size
imageSize : that fits with device orientation and camera sensor orientation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited